@@ -17,6 +17,6 @@
 #define FREERDP_VENDOR_STRING "FreeRDP"
 #define FREERDP_PRODUCT_STRING "FreeRDP"
 
-#define FREERDP_PROXY_PLUGINDIR "/usr/pkgsrc/net/freerdp2/work/freerdp-2.9.0/server/proxy/plugins"
+#define FREERDP_PROXY_PLUGINDIR "/tmp/pkgbuild/net/freerdp2/work.sparc64/freerdp-2.11.7/cmake-pkgsrc-build/server/proxy/plugins"
 
 #endif /* FREERDP_BUILD_CONFIG_H */
